Package: DistributionUtils
Version: 0.6-1
Date: 2023-08-22
Title: Distribution Utilities
Author: David Scott <d.scott@auckland.ac.nz>
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Suggests: GeneralizedHyperbolic, VarianceGamma, SkewHyperbolic, RUnit
Encoding: UTF-8
Description: Utilities are provided which are of use in the
    packages I have developed for dealing with
    distributions. Currently these packages are GeneralizedHyperbolic,
    VarianceGamma, and SkewHyperbolic and NormalLaplace. Each of these
    packages requires DistributionUtils. Functionality includes sample
    skewness and kurtosis, log-histogram, tail plots, moments by
    integration, changing the point about which a moment is
    calculated, functions for testing distributions using inversion
    tests and the Massart inequality. Also includes an implementation
    of the incomplete Bessel K function.
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2023-08-24 11:47:27 UTC; dsco036
Repository: CRAN
Date/Publication: 2023-08-28 11:30:11 UTC
Built: R 4.5.3; x86_64-apple-darwin23.6.0; 2026-04-11 18:27:41 UTC; unix
