Package: DistributionUtils
Version: 0.6-0
Date: 2018-11-26
Title: Distribution Utilities
Author: David Scott <d.scott@auckland.ac.nz>
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Suggests: GeneralizedHyperbolic, VarianceGamma, SkewHyperbolic, RUnit
Encoding: latin1
Description: Utilities are provided which are of use in the
    packages I have developed for dealing with
    distributions. Currently these packages are GeneralizedHyperbolic,
    VarianceGamma, and SkewHyperbolic and NormalLaplace. Each of these
    packages requires DistributionUtils. Functionality includes sample
    skewness and kurtosis, log-histogram, tail plots, moments by
    integration, changing the point about which a moment is
    calculated, functions for testing distributions using inversion
    tests and the Massart inequality. Also includes an implementation
    of the incomplete Bessel K function.
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2018-11-27 10:02:48 UTC; dsco036
Repository: CRAN
Date/Publication: 2018-11-27 10:40:06 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2022-02-21 19:40:23 UTC; windows
Archs: x64
