importFrom("graphics", "hist.default", "lines", "plot", "points",
           "segments")
importFrom("stats", "integrate", "median", "optimize", "pchisq",
           "pgamma", "pnorm", "ppoints", "pt", "quantile", "sd",
           "splinefun", "uniroot", "var")

################################################
### Functions
################################################
#export(newIBFR)
export(besselRatio)
export(incompleteBesselK)
export(incompleteBesselKR)
export(distIneqMassart, distIneqMassartPlot)
export(integrateDens)
export(inversionTestpq, inversionTestqp)
export(is.wholenumber)
export(logHist)
export(momChangeAbout)
export(momIntegrated)
export(momSE)
export(safeIntegrate)
export(skewness, kurtosis)
export(tailPlot, tailPlotLine)
export(normTailPlotLine, tTailPlotLine, gammaTailPlotLine)
export(tsHessian)
export(pDist, qDist)
export(distCalcRange, distMode, distStepSize)
export(moranTest)

################################################
### useDynLib
################################################
useDynLib("DistributionUtils", .registration = TRUE, .fixes = "C_")
